@@ -3,7 +3,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use IO::All;
 use YAML::XS;
@@ -22,6 +22,7 @@ field compile => 0;
 field sample => 0;
 field run => 0;
 field html => 0;
+field text => 0;
 field ghpublish => 0;
 field start => 0;
 field digits => 0;
@@ -49,6 +50,7 @@ sub usage {
     -vroom      - Start slideshow
     -compile    - Generate slides
     -html       - Publish slides as HTML
+    -text       - Publish slides as plain text
 
     -skip=#     - Skip # of slides
     -input=name - Specify an input file name
@@ -82,6 +84,9 @@ sub vroom {
     elsif ($self->html) {
         $self->makeHTML;
     }
+    elsif ($self->text) {
+        $self->makeText;
+    }
     elsif ($self->ghpublish) {
         $self->makePublisher;
     }
@@ -110,6 +115,7 @@ Create a new directory for your slides and run vroom from there.
         "compile" => \$self->{compile},
         "run" => \$self->{run},
         "html" => \$self->{html},
+        "text" => \$self->{text},
         "ghpublish" => \$self->{ghpublish},
         "input=s"  => \$self->{input},
         "vroom"  => \$self->{start},
@@ -133,6 +139,7 @@ sub cleanAll {
     my $self = shift;
     $self->cleanUp;
     io->dir('html')->rmtree;
+    io->dir('text')->rmtree;
 }
 
 sub runSlide {
@@ -187,6 +194,25 @@ sub makeSlides {
     $self->writeHelp;
 }
 
+sub makeText {
+    my $self = shift;
+    $self->cleanAll;
+    $self->makeSlides;
+    io('text')->mkdir;
+    my @slides = glob('0*');
+    for my $slide (@slides) {
+        next unless $slide =~ /^(\d+)(\.\S+)?$/;
+        my $num = $1;
+        my $ext = $2 || '';
+        my $text = io(-e "${num}z$ext" ? "${num}z$ext" : "$num$ext")->all();
+        io("text/$slide")->print($text);
+    }
+    eval {
+        system("cp .vimrc text");
+    };
+    $self->cleanUp;
+}
+
 sub makeHTML {
     my $self = shift;
     require Template::Toolkit::Simple;
@@ -411,7 +437,7 @@ sub formatNumber {
 
 my $types = {
     # add pl6 and py3
-    perl => 'pl', pl => 'pl',
+    perl => 'pl', pl => 'pl', pm => 'pm',
     ruby => 'rb', rb => 'rb',
     python => 'py', py => 'py',
     haskell => 'hs', hs => 'hs',
@@ -434,6 +460,8 @@ sub parseSlideConfig {
     my $config = {};
     my $type_list = join '|', keys %$types;
     for my $option (split /\s*,\s*/, $string) {
+        $config->{$option} = 1
+            if $option =~ /^cd/;
         $config->{$1} = 1
             if $option =~ /^(config|skip|center|replace|$type_list)$/;
         $config->{indent} = $1
@@ -482,6 +510,12 @@ sub applyOptions {
             $ext = ".$e";
             last;
         }
+        elsif ($key =~ s/^cd//) {
+            if (my $e = $types->{$key}) {
+                $ext = ".cd.$e";
+                last;
+            }
+        }
     }
     $self->ext($ext);
 
@@ -812,6 +846,11 @@ Just compile the slides.
 Publish the slides to HTML, with embedded JavaScript to navigate with
 the spacebar and backspace keys. Created in the C<html/> subdirectory.
 
+=item vroom --text
+
+Publish the slides to plain text. This action uses all the text slides in
+their unsplit form.  Created in the C<text/> subdirectory.
+
 =item vroom --clean
 
 Clean up all the compiled output files.
